@@ -17,9 +17,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
- * USA
+ * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <pyglib.h>
@@ -401,6 +399,7 @@ _caller_alloc (PyGIArgCache *arg_cache, GIArgument *arg)
             PyObject *foreign_struct =
                 pygi_struct_foreign_convert_from_g_argument (
                     iface_cache->interface_info,
+                    GI_TRANSFER_NOTHING,
                     NULL);
 
                 pygi_struct_foreign_convert_to_g_argument (foreign_struct,
